@@ -8,14 +8,17 @@
 #' check_empty_beautier_folder()
 #'
 #' # The alpha parameter must be initialized, i.e. have an ID
-#' alpha_parameter_to_xml(alpha_parameter = create_alpha_param(id = "1"))
+#' alpha_parameter_to_xml(
+#'   alpha_parameter = create_alpha_param(id = "1"),
+#'   beauti_options = create_beauti_options()
+#' )
 #'
 #' check_empty_beautier_folder()
 #' @author Richèl J.C. Bilderbeek
 #' @export
 alpha_parameter_to_xml <- function(
   alpha_parameter,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   beautier::check_beauti_options(beauti_options)
 
