@@ -24,7 +24,8 @@
 are_clock_models <- function(
   x
 ) {
-  tryCatch({
+  tryCatch(
+    {
       # We check four times. Just to check lintr-bot
       beautier::check_clock_models(x)
       TRUE
