@@ -10,8 +10,7 @@
 #' @export
 #' @aliases check_ns_mcmc check_mcmc_nested_sampling check_nested_sampling_mcmc
 #' @export check_ns_mcmc check_mcmc_nested_sampling check_nested_sampling_mcmc
-check_ns_mcmc <- check_mcmc_nested_sampling <-
-check_nested_sampling_mcmc <- function(mcmc) {
+check_ns_mcmc <- check_mcmc_nested_sampling <- check_nested_sampling_mcmc <- function(mcmc) { # nolint indeed a long line
 
   beautier::check_mcmc(mcmc)
 
