@@ -138,12 +138,16 @@ create_beta_distr <- create_distr_beta <- function(
     beta <- create_beta_param(value = beta)
   }
   if (!is_alpha_param(alpha)) {
-    stop("'alpha' must be an alpha parameter, ",
-      "as returned by 'create_alpha_param'")
+    stop(
+      "'alpha' must be an alpha parameter, ",
+      "as returned by 'create_alpha_param'"
+    )
   }
   if (!is_beta_param(beta)) {
-    stop("'beta' must be a beta parameter, ",
-      "as returned by 'create_beta_param'")
+    stop(
+      "'beta' must be a beta parameter, ",
+      "as returned by 'create_beta_param'"
+    )
   }
   if (alpha$value < 0.0) {
     stop("'alpha' must have a positive value")
@@ -202,8 +206,10 @@ create_exp_distr <- create_distr_exp <- function(
     mean <- beautier::create_mean_param(value = mean)
   }
   if (!is_mean_param(mean)) {
-    stop("'mean' must be a mean parameter, ",
-      "as returned by 'create_mean_param'")
+    stop(
+      "'mean' must be a mean parameter, ",
+      "as returned by 'create_mean_param'"
+    )
   }
   beautier::create_distr(
     name = "exponential",
@@ -268,12 +274,16 @@ create_gamma_distr <- create_distr_gamma <- function(
     beta <- create_beta_param(value = beta)
   }
   if (!is_alpha_param(alpha)) {
-    stop("'alpha' must be an alpha parameter, ",
-      "as returned by 'create_alpha_param'")
+    stop(
+      "'alpha' must be an alpha parameter, ",
+      "as returned by 'create_alpha_param'"
+    )
   }
   if (!is_beta_param(beta)) {
-    stop("'beta' must be a beta parameter, ",
-      "as returned by 'create_beta_param'")
+    stop(
+      "'beta' must be a beta parameter, ",
+      "as returned by 'create_beta_param'"
+    )
   }
   if (alpha$value < 0.0) {
     stop("'value' of 'alpha' must be positive")
@@ -341,12 +351,16 @@ create_inv_gamma_distr <- create_distr_inv_gamma <- function(
     beta <- create_beta_param(value = beta)
   }
   if (!beautier::is_alpha_param(alpha)) {
-    stop("'alpha' must be an alpha parameter, ",
-      "as returned by 'create_alpha_param'")
+    stop(
+      "'alpha' must be an alpha parameter, ",
+      "as returned by 'create_alpha_param'"
+    )
   }
   if (!beautier::is_beta_param(beta)) {
-    stop("'beta' must be a beta parameter, ",
-      "as returned by 'create_beta_param'")
+    stop(
+      "'beta' must be a beta parameter, ",
+      "as returned by 'create_beta_param'"
+    )
   }
   beautier::create_distr(
     name = "inv_gamma",
@@ -408,12 +422,16 @@ create_laplace_distr <- create_distr_laplace <- function(
   }
 
   if (!beautier::is_mu_param(mu)) {
-    stop("'mu' must be a mu parameter, ",
-      "as returned by 'create_mu_param'")
+    stop(
+      "'mu' must be a mu parameter, ",
+      "as returned by 'create_mu_param'"
+    )
   }
   if (!beautier::is_scale_param(scale)) {
-    stop("'scale' must be a scale parameter, ",
-      "as returned by 'create_scale_param'")
+    stop(
+      "'scale' must be a scale parameter, ",
+      "as returned by 'create_scale_param'"
+    )
   }
   beautier::create_distr(
     name = "laplace",
@@ -534,6 +552,9 @@ create_normal_distr <- create_distr_normal <- function(
   lower = NA,
   upper = NA
 ) {
+  if (beautier::is_one_string_that_is_a_number(mean)) {
+    mean <- beautier::create_mean_param(value = as.numeric(mean))
+  }
   if (beautier::is_one_double(mean)) {
     mean <- beautier::create_mean_param(value = mean)
   }
@@ -542,12 +563,16 @@ create_normal_distr <- create_distr_normal <- function(
   }
 
   if (!beautier::is_mean_param(mean)) {
-    stop("'mean' must be a mean parameter, ",
-      "as returned by 'create_mean_param'")
+    stop(
+      "'mean' must be a mean (as in: average) parameter, ",
+      "as returned by 'create_mean_param'"
+    )
   }
   if (!beautier::is_sigma_param(sigma)) {
-    stop("'sigma' must be a sigma parameter, ",
-      "as returned by 'create_sigma_param'")
+    stop(
+      "'sigma' must be a sigma parameter, ",
+      "as returned by 'create_sigma_param'"
+    )
   }
   beautier::create_distr(
     name = "normal",
@@ -642,7 +667,8 @@ create_poisson_distr <- create_distr_poisson <- function(
 
   if (!is_lambda_param(lambda)) {
     stop("'lambda' must be a lambda parameter, ",
-      "as returned by 'create_lambda_param'")
+      "as returned by 'create_lambda_param'"
+    )
   }
   beautier::create_distr(
     name = "poisson",
