@@ -32,8 +32,13 @@ create_strict_clock_rate_scaler_operator_xml <- function(inference_model) { # no
     "<operator id=\"StrictClockRateScaler.c:", id, "\" ",
     "spec=\"ScaleOperator\" parameter=\"@clockRate.c:", id, "\" "
   )
-  if (inference_model$beauti_options$beast2_version != "2.6") {
-    xml <- paste0(xml, "scaleFactor=\"0.75\" ")
+  if (clock_model$rate_scaler_factor != "") {
+    xml <- paste0(xml, "scaleFactor=\"", clock_model$rate_scaler_factor, "\" ")
+  }
+  if (1 == 2) {
+    if (inference_model$beauti_options$beast2_version != "2.6") {
+      xml <- paste0(xml, "scaleFactor=\"0.75\" ")
+    }
   }
   xml <- paste0(xml, "weight=\"3.0\"/>")
   xml
