@@ -104,7 +104,7 @@ create_bd_tree_prior <- create_tree_prior_bd <- function(
   id = NA,
   birth_rate_distr = create_uniform_distr(),
   death_rate_distr = create_uniform_distr()
-  ) {
+) {
   create_tree_prior(
     name = "birth_death",
     id = id,
@@ -138,12 +138,16 @@ create_bd_tree_prior <- create_tree_prior_bd <- function(
 #' @export create_cbs_tree_prior create_tree_prior_cbs
 create_cbs_tree_prior <- create_tree_prior_cbs <- function(
   id = NA,
-  group_sizes_dimension = 5
-  ) {
+  group_sizes_dimension = 5,
+  b_pop_sizes_param = create_b_pop_sizes_param(),
+  pop_sizes_scaler_scale_factor = ""
+) {
   cbs_tree_prior <- create_tree_prior(
     name = "coalescent_bayesian_skyline",
     id = id,
-    group_sizes_dimension = group_sizes_dimension
+    group_sizes_dimension = group_sizes_dimension,
+    b_pop_sizes_param = b_pop_sizes_param,
+    pop_sizes_scaler_scale_factor = pop_sizes_scaler_scale_factor
   )
   testit::assert(beautier::is_cbs_tree_prior(cbs_tree_prior))
   cbs_tree_prior
