@@ -8,14 +8,17 @@
 #' @examples
 #' check_empty_beautier_folder()
 #'
-#' distr_to_xml(create_uniform_distr(id = 1))
+#' distr_to_xml(
+#'   create_uniform_distr(id = 1),
+#'   beauti_options = create_beauti_options()
+#' )
 #'
 #' check_empty_beautier_folder()
 #' @author Richèl J.C. Bilderbeek
 #' @export
 distr_to_xml <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   beautier::check_beauti_options(beauti_options)
   text <- NULL
@@ -60,7 +63,7 @@ distr_to_xml <- function(
 #' @export
 distr_to_xml_beta <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_beta_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -71,12 +74,18 @@ distr_to_xml_beta <- function(
   text <- c(text, paste0("<Beta id=\"Beta.", id, "\" name=\"distr\">"))
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$alpha)
+      beautier::parameter_to_xml(
+        distr$alpha,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$beta)
+      beautier::parameter_to_xml(
+        distr$beta,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</Beta>"))
@@ -94,7 +103,7 @@ distr_to_xml_beta <- function(
 #' @export
 distr_to_xml_exp <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_exp_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -102,11 +111,19 @@ distr_to_xml_exp <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<Exponential ",
-    "id=\"Exponential.", id, "\" name=\"distr\">"))
+  text <- c(
+    text,
+    paste0(
+      "<Exponential ",
+      "id=\"Exponential.", id, "\" name=\"distr\">"
+    )
+  )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$mean)
+      beautier::parameter_to_xml(
+        distr$mean,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</Exponential>"))
@@ -124,7 +141,7 @@ distr_to_xml_exp <- function(
 #' @export
 distr_to_xml_inv_gamma <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_inv_gamma_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -132,16 +149,27 @@ distr_to_xml_inv_gamma <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<InverseGamma ",
-    "id=\"InverseGamma.", id, "\" name=\"distr\">"))
-  text <- c(text,
-    beautier::indent(
-      beautier::parameter_to_xml(distr$alpha)
+  text <- c(
+    text,
+    paste0(
+      "<InverseGamma ",
+      "id=\"InverseGamma.", id, "\" name=\"distr\">"
     )
   )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$beta)
+      beautier::parameter_to_xml(
+        distr$alpha,
+        beauti_options = beauti_options
+      )
+    )
+  )
+  text <- c(text,
+    beautier::indent(
+      beautier::parameter_to_xml(
+        distr$beta,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</InverseGamma>"))
@@ -159,7 +187,7 @@ distr_to_xml_inv_gamma <- function(
 #' @export
 distr_to_xml_laplace <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_laplace_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -167,16 +195,27 @@ distr_to_xml_laplace <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<LaplaceDistribution ",
-    "id=\"LaplaceDistribution.", id, "\" name=\"distr\">"))
-  text <- c(text,
-    beautier::indent(
-      beautier::parameter_to_xml(distr$mu)
+  text <- c(
+    text,
+    paste0(
+      "<LaplaceDistribution ",
+      "id=\"LaplaceDistribution.", id, "\" name=\"distr\">"
     )
   )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$scale)
+      beautier::parameter_to_xml(
+        distr$mu,
+        beauti_options = beauti_options
+      )
+    )
+  )
+  text <- c(text,
+    beautier::indent(
+      beautier::parameter_to_xml(
+        distr$scale,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</LaplaceDistribution>"))
@@ -194,7 +233,7 @@ distr_to_xml_laplace <- function(
 #' @export
 distr_to_xml_log_normal <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_log_normal_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -202,16 +241,27 @@ distr_to_xml_log_normal <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<LogNormal ",
-    "id=\"LogNormalDistributionModel.", id, "\" name=\"distr\">"))
-  text <- c(text,
-    beautier::indent(
-      beautier::parameter_to_xml(distr$m)
+  text <- c(
+    text,
+    paste0(
+      "<LogNormal ",
+      "id=\"LogNormalDistributionModel.", id, "\" name=\"distr\">"
     )
   )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$s)
+      beautier::parameter_to_xml(
+        distr$m,
+        beauti_options = beauti_options
+      )
+    )
+  )
+  text <- c(text,
+    beautier::indent(
+      beautier::parameter_to_xml(
+        distr$s,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</LogNormal>"))
@@ -230,7 +280,7 @@ distr_to_xml_log_normal <- function(
 #' @export
 distr_to_xml_normal <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_normal_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -238,16 +288,27 @@ distr_to_xml_normal <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<Normal ",
-    "id=\"Normal.", id, "\" name=\"distr\">"))
-  text <- c(text,
-    beautier::indent(
-      beautier::parameter_to_xml(distr$mean)
+  text <- c(
+    text,
+    paste0(
+      "<Normal ",
+      "id=\"Normal.", id, "\" name=\"distr\">"
     )
   )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$sigma)
+      beautier::parameter_to_xml(
+        distr$mean,
+        beauti_options = beauti_options
+      )
+    )
+  )
+  text <- c(text,
+    beautier::indent(
+      beautier::parameter_to_xml(
+        distr$sigma,
+        beauti_options = beauti_options
+      )
     )
   )
   text <- c(text, paste0("</Normal>"))
@@ -265,7 +326,7 @@ distr_to_xml_normal <- function(
 #' @export
 distr_to_xml_one_div_x <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_one_div_x_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -289,7 +350,7 @@ distr_to_xml_one_div_x <- function(
 #' @export
 distr_to_xml_poisson <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_poisson_distr(distr))
   beautier::check_beauti_options(beauti_options)
@@ -297,12 +358,20 @@ distr_to_xml_poisson <- function(
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  text <- c(text, paste0("<distr ",
-    "id=\"Poisson.", id, "\" ",
-    "spec=\"beast.math.distributions.Poisson\">"))
+  text <- c(
+    text,
+    paste0(
+      "<distr ",
+      "id=\"Poisson.", id, "\" ",
+      "spec=\"beast.math.distributions.Poisson\">"
+    )
+  )
   text <- c(text,
     beautier::indent(
-      beautier::parameter_to_xml(distr$lambda),
+      beautier::parameter_to_xml(
+        distr$lambda,
+        beauti_options = beauti_options
+      ),
     )
   )
   text <- c(text, paste0("</distr>"))
@@ -320,7 +389,7 @@ distr_to_xml_poisson <- function(
 #' @export
 distr_to_xml_uniform <- function(
   distr,
-  beauti_options = create_beauti_options()
+  beauti_options
 ) {
   testit::assert(beautier::is_uniform_distr(distr))
   beautier::check_beauti_options(beauti_options)
