@@ -11,9 +11,12 @@
 get_param_names <- function() {
   c(
     "alpha",
+    "b_pop_sizes", # bPopSizes
     "beta",
     "clock_rate",
+    "freqParameter", # BEAST2 redundant naming: 'freq' is the name of a parameter # nolint
     "lambda",
+    "kappa",
     "kappa_1",
     "kappa_2",
     "m",
