@@ -15,12 +15,18 @@
 #' check_empty_beautier_folder()
 #' @author Richèl J.C. Bilderbeek
 #' @export
-site_models_to_xml_prior_distr <- function(site_models) {
+site_models_to_xml_prior_distr <- function(
+  site_models,
+  beauti_options
+) {
   text <- NULL
   for (site_model in site_models) {
     text <- c(
       text,
-      beautier::site_model_to_xml_prior_distr(site_model)
+      beautier::site_model_to_xml_prior_distr(
+        site_model,
+        beauti_options = beauti_options
+      )
     )
   }
   text
