@@ -25,9 +25,13 @@ tree_model_to_tracelog_xml <- function(
   testthat::expect_true(beautier::is_id(id))
   text <- NULL
   text <- c(text, paste0("<log idref=\"treeLikelihood.", id, "\"/>")) # nolint this is no absolute path
-  text <- c(text, paste0("<log id=\"TreeHeight.t:", id, "\" ",
-    "spec=\"beast.evolution.tree.TreeHeightLogger\" ",
-    "tree=\"@Tree.t:", id, "\"/>") # nolint this is no absolute path
+  text <- c(
+    text,
+    paste0(
+      "<log id=\"TreeHeight.t:", id, "\" ",
+      "spec=\"beast.evolution.tree.TreeHeightLogger\" ",
+      "tree=\"@Tree.t:", id, "\"/>"
+    )
   )
   text
 }
